#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2023-10-20 created

function change_file_permission() {
    local file="$1"
    local num="$2"
    if [ -f "${file}" ]; then
        chmod "${num}" "${file}"
    fi
}

function init_env() {
    INSTALL_INI_PATH="${INSTALL_PATH}/config/install.ini"
    source ${INSTALL_PATH}/tools/log.sh
    if [[ ! -f "${INSTALL_INI_PATH}" ]]; then
		echo_and_log "There is no configure file(${INSTALL_INI_PATH}), please check!" "${ERROR}"
		exit "${ERROR}"
	fi
    USER_PATH="$(grep -w USER_PATH "${INSTALL_INI_PATH}" | awk -F= '{if($2 !="") print $2}')"
    USER_NAME="$(grep -w USER_NAME "${INSTALL_INI_PATH}" | awk -F= '{if($2 !="") print $2}')"
    CUDA_GDB_PATH=$(which cuda-gdb 2>/dev/null)
    if [[ -e ${CUDA_GDB_PATH} ]]; then
        CUDA_BIN_PATH="$(dirname ${CUDA_GDB_PATH})"
        echo "CUDA_GDB_BIN_PATH=${CUDA_BIN_PATH}" >> ${INSTALL_PATH}/devkitplugins/debugger/config/install.ini
    fi
}

function write_local_ip_to_config() {
    ip_addr=$(ip addr|grep inet|grep -v 127.0.0.1|grep -v inet6|awk '{print $2}' |tr '\n' ' ')
    echo "LOCAL_IP=${ip_addr}" >> ${INSTALL_PATH}/devkitplugins/debugger/config/install.ini
}

function version_gt(){
    test "$(echo $@ | tr " " "\n" | sort -rV | head -n 1)" == "$1"
}

function compare_libstdc_version() {
    libstdc_version_of_tools="6.0.24"
    path_list=(/usr/lib64/ /usr/lib/ /lib64/ /lib /libx32)
    for path in "${path_list[@]}"; do
        if [[ -d $path ]]; then
            result=$(find $path -name libstdc++.so.6.*)
            if [[ -n "$result" ]]; then
                libstdc_version_of_system=$(echo "$result" | tr " " "\n" | sort -rV | head -n 1 | grep -Po "\d+\.\d+\.\d+")
                if version_gt "$libstdc_version_of_tools" "$libstdc_version_of_system"; then
                    libstdcflag="true"
                else
                    libstdcflag="false"
                fi
                break
            fi
        fi
    done
}

function main() {
    INSTALL_PATH="$1"
    init_env
    write_local_ip_to_config
	change_file_permission "${INSTALL_PATH}/devkitplugins/debugger/config/request_param.conf" 600
	if [[ "$libstdcflag" == "true" || -z "$libstdcflag" ]]; then
			cp -n ${INSTALL_PATH}/devkitplugins/debugger/cmd/lib/libstdc++.so.6* /${USER_PATH}/lib
			chmod 600 ${USER_PATH}/lib/*
			chown ${USER_NAME}:${USER_NAME} ${USER_PATH}/lib/libstdc++.so.6*
	fi
}

main "$@"